Package: energyr
Version: 0.4
Title: Data Published by the United States Federal Energy Regulatory
        Commission
Description: Data published by the United States Federal Energy Regulatory Commission including
    electric company financial data, natural gas company financial data, 
    hydropower plant data, liquified natural gas plant data, oil company financial data
    natural gas company financial data, and natural gas storage field data.
URL: https://github.com/paulgovan/energyr,
        http://paulgovan.github.io/energyr/
BugReports: https://github.com/paulgovan/energyr/issues
Authors@R: person("Paul", "Govan", email = "paul.govan2@gmail.com", role = c("aut", "cre", "cph"), comment = c(ORCID = "0000-0002-1821-8492"))
Depends: R (>= 3.5.0)
Suggests: here, tidygeocoder, usethis, testthat (>= 3.0.0)
License: CC BY 4.0
LazyData: TRUE
RoxygenNote: 7.2.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-18 23:58:44 UTC; paulgovan
Author: Paul Govan [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-1821-8492>)
Maintainer: Paul Govan <paul.govan2@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-19 05:10:19 UTC
Built: R 4.6.0; ; 2026-04-25 18:29:05 UTC; unix
