#' Natural Gas Storage Field Information Data
#'
#' Natural Gas Storage Field Information as reported by FERC. Data includes the
#' name of the storage company, field, reservoir, type, location, working and total
#' capacity, and maximum daily delivery. 
#'
#' @source \url{https://www.ferc.gov/industries-data/natural-gas/overview/gas-storage}
#' @format Data frame with columns
#' \describe{
#' \item{Company}{Name of the Storage Company}
#' \item{Field}{Name of the Storage Field}
#' \item{Reservoir}{Name of the Storage Reservoir}
#' \item{Type}{Type of Storage Field}
#' \item{County}{County Where the Field is Located}
#' \item{State}{State Where the Field is Located}
#' \item{Region}{AGA Region Where the Field is Located}
#' \item{Working}{Working Capacity in Mcf}
#' \item{Total}{Total Capacity in Mcf}
#' \item{MDD}{Maximum Daily Delivery in McF}
#' \item{address}{Location of the Field}
#' \item{lat}{Approximate Latitude of the Field}
#' \item{lon}{Approximate Longitude of the Field}
#' }
#' @examples
#' data(storage)
#' dim(storage)
#' head(storage)
"storage"
