#' An R package containing Federal Energy Regularity Commission (FERC) data
#'
#' energyr is an R package containing data from http://www.ferc.gov.
#'
#' @section energyr functions:
#' electric
#' gas
#' hydropower
#' lng
#' oil
#' pipeline
#' storage
#'
#' @docType package
#' @name energyr
NULL
